function varargout = Gaussian_Quad_Help(varargin)
% GAUSSIAN_QUAD_HELP M-file for Gaussian_Quad_Help.fig
%      GAUSSIAN_QUAD_HELP, by itself, creates a new GAUSSIAN_QUAD_HELP or raises the existing
%      singleton*.
%
%      H = GAUSSIAN_QUAD_HELP returns the handle to a new GAUSSIAN_QUAD_HELP or the handle to
%      the existing singleton*.
%
%      GAUSSIAN_QUAD_HELP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in GAUSSIAN_QUAD_HELP.M with the given input arguments.
%
%      GAUSSIAN_QUAD_HELP('Property','Value',...) creates a new GAUSSIAN_QUAD_HELP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Gaussian_Quad_Help_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Gaussian_Quad_Help_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help Gaussian_Quad_Help

% Last Modified by GUIDE v2.5 28-Aug-2004 18:41:12

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Gaussian_Quad_Help_OpeningFcn, ...
                   'gui_OutputFcn',  @Gaussian_Quad_Help_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Gaussian_Quad_Help is made visible.
function Gaussian_Quad_Help_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Gaussian_Quad_Help (see VARARGIN)

% Choose default command line output for Gaussian_Quad_Help
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Gaussian_Quad_Help wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Gaussian_Quad_Help_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --------------------------------------------------------------------
function Close_Callback(hObject, eventdata, handles)
% hObject    handle to Close (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

delete(handles.figure1)

% --------------------------------------------------------------------
function File_Menu_Callback(hObject, eventdata, handles)
% hObject    handle to File_Menu (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


